@@ -16,11 +16,12 @@ from sqlalchemy import create_engine
 from sqlalchemy.orm import sessionmaker
 from sqlalchemy.pool import SingletonThreadPool
 
-from ..orm import metadata
+from ..orm import metadata, ProjectFile
 
 logging.basicConfig()
 log = logging.getLogger(__name__)
 
+
 def del_sqlite_db(path):
     """
     Delete sqlite database
@@ -32,16 +33,17 @@ def del_sqlite_db(path):
 
 
 def init_db(sqlalchemy_url):
-    '''
+    """
     Initialize database with gsshapy tables
-    '''
+    """
     engine = create_engine(sqlalchemy_url)
     start = time.time()
     metadata.create_all(engine)
     return time.time() - start
-    
+
+
 def init_sqlite_memory(initTime=False):
-    '''
+    """
     Initialize SQLite in Memory Only Database
     
     Args:
@@ -56,16 +58,15 @@ def init_sqlite_memory(initTime=False):
     
         from gsshapy.lib.db_tools import init_sqlite_memory, create_session
         
-        sqlite_db_path = '/home/username/my_sqlite.db'   
-        
-        sqlalchemy_url, engine = init_postgresql_db(path=sqlite_db_path)
-        
-        db_work_session = create_session(sqlalchemy_url, engine)
+        sqlalchemy_url, engine = init_sqlite_memory()
         
+        db_work_sessionmaker = get_sessionmaker(sqlalchemy_url, engine)
+
+        db_work_session = db_work_sessionmaker()
         ##DO WORK
         
         db_work_session.close()
-    '''
+    """
     sqlalchemy_url = 'sqlite://'
     engine = create_engine(sqlalchemy_url,
                            poolclass=SingletonThreadPool)
@@ -79,7 +80,7 @@ def init_sqlite_memory(initTime=False):
     
     
 def init_sqlite_db(path, initTime=False):
-    '''
+    """
     Initialize SQLite Database
     
     Args:
@@ -94,14 +95,16 @@ def init_sqlite_db(path, initTime=False):
         
         init_postgresql_db(path=sqlite_db_path)
         
-        sqlalchemy_url = init_postgresql_db(path=sqlite_db_path)
+        sqlalchemy_url = init_sqlite_db(path=sqlite_db_path)
         
-        db_work_session = create_session(sqlalchemy_url)
+        db_work_sessionmaker = get_sessionmaker(sqlalchemy_url)
+
+        db_work_session = db_work_sessionmaker()
         
         ##DO WORK
         
         db_work_session.close()
-    '''
+    """
     sqlite_base_url = 'sqlite:///'
     
     sqlalchemy_url = sqlite_base_url + path
@@ -115,7 +118,7 @@ def init_sqlite_db(path, initTime=False):
     
     
 def init_postgresql_db(username, host, database, port='', password='', initTime=False):
-    '''
+    """
     Initialize PostgreSQL Database
     
     .. note:: psycopg2 or similar driver required
@@ -138,12 +141,14 @@ def init_postgresql_db(username, host, database, port='', password='', initTime=
                                             port='5432', 
                                             password='pass')
 
-        db_work_session = create_session(sqlalchemy_url)
+        db_work_sessionmaker = get_sessionmaker(sqlalchemy_url)
+
+        db_work_session = db_work_sessionmaker()
         
         ##DO WORK
         
         db_work_session.close()
-    '''
+    """
     postgresql_base_url = 'postgresql://'
     
     if password != '':
@@ -167,9 +172,10 @@ def init_postgresql_db(username, host, database, port='', password='', initTime=
         print('TIME: {0} seconds'.format(init_time))
     
     return sqlalchemy_url
-        
+
+
 def init_mysql_db(username, host, database, port='', password='', initTime=False):
-    '''
+    """
     Initialize MySQL Database
     
     .. note:: mysql-python or similar driver required
@@ -192,12 +198,13 @@ def init_mysql_db(username, host, database, port='', password='', initTime=False
                                        port='5432', 
                                        password='pass')
                                        
-        db_work_session = create_session(sqlalchemy_url)
-        
+        db_work_sessionmaker = get_sessionmaker(sqlalchemy_url)
+
+        db_work_session = db_work_sessionmaker()
         ##DO WORK
         
         db_work_session.close()
-    '''
+    """
     
     mysql_base_url = 'mysql://'
     
@@ -223,13 +230,23 @@ def init_mysql_db(username, host, database, port='', password='', initTime=False
     
     return sqlalchemy_url
 
-def create_session(sqlalchemy_url, engine=None):
-    '''
+
+def get_sessionmaker(sqlalchemy_url, engine=None):
+    """
     Create session with database to work in
-    '''
+    """
     if engine is None:
         engine = create_engine(sqlalchemy_url)
-    maker = sessionmaker(bind=engine)
-    session = maker()
-    return session
-    
\ No newline at end of file
+    return sessionmaker(bind=engine)
+
+
+def get_project_session(project_name, project_directory, map_type=None):
+    """
+    Load project manager and in memory sqlite db sessionmaker for GSSHA project
+    """
+    sqlalchemy_url, sql_engine = init_sqlite_memory()
+    gdb_sessionmaker = get_sessionmaker(sqlalchemy_url, sql_engine)
+    project_manager = ProjectFile(name=project_name,
+                                  project_directory=project_directory,
+                                  map_type=map_type)
+    return project_manager, gdb_sessionmaker
